@@ -376,7 +376,8 @@ class ScreenCommands(Commands):
     @command('screen.lineselection.begin')
     @norerun
     def lineselection_begin(self, wnd):
-        tol = wnd.cursor.adjust_nextpos(wnd.document.gettol(wnd.cursor.pos))
+        tol = wnd.cursor.adjust_nextpos(
+            wnd.cursor.pos, wnd.document.gettol(wnd.cursor.pos))
         wnd.screen.selection.begin_cursor(tol)
 
     @command('screen.lineselection.set-end')
@@ -398,6 +399,7 @@ class ScreenCommands(Commands):
 
 
 class EditCommands(Commands):
+
     def delete_sel(self, wnd):
         if wnd.screen.selection.is_selected():
             if not wnd.screen.selection.is_rectangular():
@@ -774,7 +776,6 @@ class EditCommands(Commands):
         texthistmode.show_history(callback, words)
 
 
-
 class CodeCommands(Commands):
 
     @command('code.region.linecomment')
