@@ -36,10 +36,17 @@ class DirFileListMode(selectlist.SelectItemList):
         wnd.set_label('filelist', wnd)
 
     def set_dir(self, dirname):
-        self.caption = self.dirname = os.path.abspath(
-            os.path.expanduser(dirname))
+        try:
+            dirname = os.path.expanduser(dirname)
+            dirname = os.path.abspath(dirname)
+        except IOError:
+            pass
+
+        self.caption = self.dirname = dirname
         self.read_dir()
 
+    MAX_DIR_ITEMS = 2000
+
     def read_dir(self):
         try:
             self.dirs, self.files = kaa.app.storage.listdir(self.dirname)
@@ -48,6 +55,9 @@ class DirFileListMode(selectlist.SelectItemList):
             self.dirs = []
             self.files = []
 
+        self.dirs = self.dirs[:self.MAX_DIR_ITEMS]
+        self.files = self.files[:self.MAX_DIR_ITEMS]
+
         # add '..' if dir is not root
         if self.dirname != '/':
             if os.path.exists(os.path.join(self.dirname, '..')):
@@ -296,7 +306,6 @@ class OpenFilenameDlgMode(dialogmode.DialogMode):
             filelist.get_label('popup').on_console_resized()
 
     def on_esc_pressed(self, wnd, event):
-        super().on_esc_pressed(wnd, event)
         popup = wnd.get_label('popup')
         popup.destroy()
         kaa.app.messagebar.set_message("")
@@ -457,8 +466,13 @@ def show_filesaveas(filename, encoding, newline, callback):
     if not filename:
         filename = kaa.app.last_dir
 
-    filename = os.path.abspath(
-        os.path.expanduser(filename))
+    try:
+        filename = os.path.abspath(
+            os.path.expanduser(filename))
+    except IOError:
+        # current directry may deleted
+        pass
+
     if os.path.isdir(filename) and not filename.endswith(os.path.sep):
         filename += os.path.sep
 
