@@ -1,7 +1,7 @@
 import kaa_testutils
 from kaa import highlight
 from kaa.filetype.html import htmlmode
-from kaa.filetype.html import get_encoding
+from kaa.filetype.html.htmlmode import get_encoding
 
 class TestHTMLHighlight(kaa_testutils._TestDocBase):
     tokenizers = htmlmode.build_tokenizers()
@@ -249,12 +249,12 @@ class TestHTMLHighlight(kaa_testutils._TestDocBase):
 
 class TestEncDecl:
     def test_html5(self):
-        assert b'UTF-8' == get_encoding(b'<meta charset="UTF-8">')
-        assert b'UTF-8' == get_encoding(b"<meta charset='UTF-8'>")
+        assert 'UTF-8' == get_encoding(b'<meta charset="UTF-8">')
+        assert 'UTF-8' == get_encoding(b"<meta charset='UTF-8'>")
         assert not  get_encoding(b"<meta charset='UTF-8>")
 
     def test_html(self):
-        assert b'UTF-8' == get_encoding(
+        assert 'UTF-8' == get_encoding(
             b'''<meta http-equiv="Content-type"
             content="text/html;charset=UTF-8">''')
 
@@ -265,7 +265,7 @@ class TestEncDecl:
             b'''<meta content="text/html;char=UTF-8">''')
 
     def test_xml(self):
-        assert b'UTF-8' == get_encoding(
+        assert 'UTF-8' == get_encoding(
                 b'<?xml version="1.0" encoding="UTF-8"?>')
 
         assert not get_encoding(
